DisplaySync

Enum DisplaySync 

pub enum DisplaySync {
    Block,
    Recent,
    Tear,
}
Mechanism used to acquire frames and display them on screen.

Variants



Block

Block until the oldest frame is released.



Recent

Display the most recently presented frame. Falls back to Tear if unsupported.



Tear

Tear the currently displayed frame when presenting a new one.